@@ -16,14 +16,19 @@ import subprocess
 
 
 @contextlib.contextmanager
-def closed_tempfile(suffix, text=None):
-    with tempfile.NamedTemporaryFile('w+t', suffix=suffix, delete=False) as test_file:
+def closed_tempfile(suffix, text=None, dir_name=None):
+    if dir_name:
+        dir_name = tempfile.mkdtemp(suffix=dir_name)
+    with tempfile.NamedTemporaryFile('w+t', suffix=suffix, delete=False, dir=dir_name) as test_file:
         file_name = test_file.name
         if text:
             test_file.write(text)
             test_file.flush()
     yield file_name
-    shutil.rmtree(file_name, ignore_errors=True)
+    if dir_name:
+        shutil.rmtree(dir_name, ignore_errors=True)
+    else:
+        os.remove(file_name)
 
 
 # Stolen from pandas
@@ -171,7 +176,7 @@ class TestPypandoc(unittest.TestCase):
     def test_convert_with_custom_writer(self):
         lua_file_content = self.create_sample_lua()
         with closed_tempfile('.md', text='#title\n') as file_name:
-            with closed_tempfile('.lua', text=lua_file_content) as lua_file_name:
+            with closed_tempfile('.lua', text=lua_file_content, dir_name="foo-bar+baz") as lua_file_name:
                 expected = u'<h1 id="title">title</h1>{0}'.format(os.linesep)
                 received = pypandoc.convert_file(file_name, lua_file_name)
                 self.assertEqualExceptForNewlineEnd(expected, received)
@@ -327,19 +332,19 @@ class TestPypandoc(unittest.TestCase):
 
         self.assertRaises(RuntimeError, f)
 
-        def f():
-            # outputfile needs to end in pdf
-            with closed_tempfile('.WRONG') as file_name:
+        # outputfile needs to end in pdf
+        with closed_tempfile('.WRONG') as file_name:
+            def f():
                 pypandoc.convert_text('#some title\n', to='pdf', format='md', outputfile=file_name)
 
-        self.assertRaises(RuntimeError, f)
+            self.assertRaises(RuntimeError, f)
 
-        def f():
-            # no extensions allowed
-            with closed_tempfile('.pdf') as file_name:
+        # no extensions allowed
+        with closed_tempfile('.pdf') as file_name:
+            def f():
                 pypandoc.convert_text('#some title\n', to='pdf+somethign', format='md', outputfile=file_name)
 
-        self.assertRaises(RuntimeError, f)
+            self.assertRaises(RuntimeError, f)
 
     def test_get_pandoc_path(self):
         result = pypandoc.get_pandoc_path()
